{% load static %}
<!DOCTYPE html>
<html>
    <head>
        {% include './_meta.html' %}
        {% include './_favicons.html' %}
        {% block custom_css %}
            <link rel="stylesheet" type="text/css" href="{% static 'css/starter.css' %}">
            <link rel="stylesheet" href="https://unpkg.com/pyloncss@latest/css/pylon.css">
            <link rel="stylesheet" href="https://cdn.jsdelivr.net/simplemde/latest/simplemde.min.css">
            {% block extra_css %}
            {% endblock extra_css %}
        {% endblock custom_css %}
    </head>
    <body>
        {% include './_nav.html' %}
        {% include './_messages.html' %}
        {% block body %}
            {% block content %}
            {% endblock content %}
            {% block base_js %}
                <script src="https://cdn.jsdelivr.net/simplemde/latest/simplemde.min.js"></script>
                <script src="https://unpkg.com/htmx.org@1.6.1"></script>
                <script src="https://unpkg.com/hyperscript.org@0.9.0"></script>
                <script>document.body.addEventListener("htmx:configRequest", (e) => {e.detail.headers["X-CSRFToken"] = "{{ csrf_token }}";});</script>
                {% block extra_js %}
                {% endblock extra_js %}
            {% endblock base_js %}
        {% endblock body %}
    </body>
</html>
