{% load static %}
<link rel="shortcut icon" type="image/png" href="{% static 'img/favicon.ico' %}"/>
<link rel="apple-touch-icon" sizes="180x180" href="{% static 'img/favicons/apple-touch-icon.png' %}">
<link rel="icon" type="image/png" sizes="32x32" href="{% static 'img/favicons/favicon-32x32.png' %}">
<link rel="icon" type="image/png" sizes="16x16" href="{% static 'img/favicons/favicon-16x16.png' %}">
<link rel="manifest" href="{% static 'img/favicons/site.webmanifest' %}">
