{% extends 'base.html' %}
{% block title %} About | BrandX {% endblock title %}
{% block content %}
    <h1>About</h1>
    <main>
        <article>
            <div class="ph4 ph5-m ph6-l">
                <div class="pv5 f4 f2-ns measure center">
                    <p>Sample <mark>text</mark> highlighted for illustration.</p>
                    <blockquote>This is a blockquote<br>- <cite>Quoting from a random person</cite></blockquote>
                    {% lorem 2 p random %}
                </div>
            </div>
        </article>
    </main>
{% endblock content %}
