{% extends 'base.html' %}

{% block title %}{{edit_header|title}} | BrandX {% endblock title %}

{% block content %}
    <h1>{{edit_header|title}}</h1>
    <main>{% include '_form.html' %}</main>
{% endblock content %}

{% block extra_js %}<script type="text/javascript">var simplemde = new SimpleMDE({forceSync: true});</script>{% endblock extra_js %}
